@@ -7,10 +7,10 @@ These are additional urls used by the Sentry-provided web server
 :copyright: (c) 2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
 
 import os
 
-from sentry.web.urls import urlpatterns as web_urlpatterns
 try:
     from django.conf.urls import include, patterns, url
 except ImportError:
@@ -19,10 +19,13 @@ except ImportError:
 from django.contrib import admin
 from django.views.defaults import page_not_found
 
+from sentry.web.urls import urlpatterns as web_urlpatterns
+from sentry.web.frontend.csrf_failure import CsrfFailureView
+
+
 admin.autodiscover()
 admin_media_dir = os.path.join(os.path.dirname(admin.__file__), 'media')
 
-
 handler404 = lambda x: page_not_found(x, template_name='sentry/404.html')
 
 
@@ -41,6 +44,10 @@ def handler500(request):
     t = loader.get_template('sentry/500.html')
     return HttpResponseServerError(t.render(Context(context)))
 
+
 urlpatterns = patterns('',
     url(r'^admin/', include(admin.site.urls)),
+    url(r'^500/', handler500, name='error-500'),
+    url(r'^404/', handler404, name='error-400'),
+    url(r'^403-csrf-failure/', CsrfFailureView.as_view(), name='error-403-csrf-failure'),
 ) + web_urlpatterns
