@@ -2,12 +2,14 @@
 sentry.db.models.fields
 ~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
 from __future__ import absolute_import
 
 from .bounded import *  # NOQA
+from .foreignkey import *  # NOQA
 from .gzippeddict import *  # NOQA
 from .node import *  # NOQA
+from .pickle import *  # NOQA
