@@ -2,13 +2,13 @@
 sentry.filters
 ~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
 
 from sentry.filters.base import *  # NOQA
 from sentry.filters.builtins import *  # NOQA
-from sentry.filters.helpers import *  # NOQA
 from sentry.filters.widgets import *  # NOQA
 
 # Backwards compatibility
