@@ -5,12 +5,14 @@ sentry.management.commands.cleanup
 :copyright: (c) 2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import, print_function
+
 from django.core.management.base import BaseCommand
 from optparse import make_option
 
 
 class Command(BaseCommand):
-    help = 'Performs any pending database migrations and upgrades'
+    help = 'Deletes a portion of trailing data based on creation date'
 
     option_list = BaseCommand.option_list + (
         make_option('--days', default='30', type=int, help='Numbers of days to truncate on.'),
