@@ -2,15 +2,18 @@
 sentry.plugins.sentry_mail.models
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
+
 import sentry
 
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
+
 from sentry.plugins import register
 from sentry.plugins.bases.notify import NotificationPlugin
 from sentry.utils.cache import cache
@@ -32,7 +35,7 @@ class MailPlugin(NotificationPlugin):
     subject_prefix = settings.EMAIL_SUBJECT_PREFIX
 
     def _send_mail(self, subject, template=None, html_template=None, body=None,
-                   project=None, headers=None, context=None, fail_silently=False):
+                   project=None, group=None, headers=None, context=None):
         send_to = self.get_send_to(project)
         if not send_to:
             return
@@ -46,16 +49,16 @@ class MailPlugin(NotificationPlugin):
             body=body,
             headers=headers,
             context=context,
+            reference=group,
         )
         msg.add_users(send_to, project=project)
-        return msg.send(fail_silently=fail_silently)
+        return msg.send()
 
     def send_test_mail(self, project=None):
         self._send_mail(
             subject='Test Email',
             body='This email was requested as a test of Sentry\'s outgoing email',
             project=project,
-            fail_silently=False,
         )
 
     def get_notification_settings_url(self):
@@ -63,13 +66,14 @@ class MailPlugin(NotificationPlugin):
 
     def get_project_url(self, project):
         return absolute_uri(reverse('sentry-stream', args=[
-            project.team.slug,
+            project.organization.slug,
             project.slug,
         ]))
 
     def on_alert(self, alert):
         project = alert.project
-        subject = '[{0}] ALERT: {1}'.format(
+        subject = '[{0} {1}] ALERT: {2}'.format(
+            project.team.name.encode('utf-8'),
             project.name.encode('utf-8'),
             alert.message.encode('utf-8'),
         )
@@ -90,11 +94,17 @@ class MailPlugin(NotificationPlugin):
             template=template,
             html_template=html_template,
             project=project,
-            fail_silently=False,
             headers=headers,
             context=context,
         )
 
+    def should_notify(self, group, event):
+        send_to = self.get_sendable_users(group.project)
+        if not send_to:
+            return False
+
+        return super(MailPlugin, self).should_notify(group, event)
+
     def get_send_to(self, project=None):
         """
         Returns a list of email addresses for the users that should be notified of alerts.
@@ -124,7 +134,9 @@ class MailPlugin(NotificationPlugin):
 
         return send_to_list
 
-    def notify_users(self, group, event, fail_silently=False):
+    def notify(self, notification):
+        event = notification.event
+        group = event.group
         project = group.project
 
         interface_list = []
@@ -134,30 +146,35 @@ class MailPlugin(NotificationPlugin):
                 continue
             interface_list.append((interface.get_title(), mark_safe(body)))
 
-        subject = '[%s] %s: %s' % (
-            project.name.encode('utf-8'),
-            unicode(event.get_level_display()).upper().encode('utf-8'),
-            event.error().encode('utf-8').splitlines()[0])
+        subject = group.get_email_subject()
 
         link = group.get_absolute_url()
 
         template = 'sentry/emails/error.txt'
         html_template = 'sentry/emails/error.html'
 
+        rule = notification.rule
+        if rule:
+            rule_link = reverse('sentry-edit-project-rule', args=[
+                group.organization.slug, project.slug, rule.id
+            ])
+        else:
+            rule_link = None
+
         context = {
             'group': group,
             'event': event,
             'tags': event.get_tags(),
             'link': link,
             'interfaces': interface_list,
+            'rule': rule,
         }
 
         headers = {
-            'X-Sentry-Logger': event.logger,
-            'X-Sentry-Logger-Level': event.get_level_display(),
+            'X-Sentry-Logger': group.logger,
+            'X-Sentry-Logger-Level': group.get_level_display(),
             'X-Sentry-Project': project.name,
-            'X-Sentry-Server': event.server_name,
-            'X-Sentry-Reply-To': group_id_to_email(group.pk),
+            'X-Sentry-Reply-To': group_id_to_email(group.id),
         }
 
         self._send_mail(
@@ -165,7 +182,7 @@ class MailPlugin(NotificationPlugin):
             template=template,
             html_template=html_template,
             project=project,
-            fail_silently=fail_silently,
+            group=group,
             headers=headers,
             context=context,
         )
