@@ -2,13 +2,15 @@
 sentry.plugins.sentry_useragents.models
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-import httpagentparser
+from __future__ import absolute_import
+
 import sentry
 
 from django.utils.translation import ugettext_lazy as _
+from ua_parser.user_agent_parser import Parse
 
 from sentry.plugins import register
 from sentry.plugins.bases.tag import TagPlugin
@@ -28,7 +30,7 @@ class UserAgentPlugin(TagPlugin):
             return []
         if 'User-Agent' not in http.headers:
             return []
-        ua = httpagentparser.detect(http.headers['User-Agent'])
+        ua = Parse(http.headers['User-Agent'])
         if not ua:
             return []
         result = self.get_tag_from_ua(ua)
@@ -40,7 +42,7 @@ class UserAgentPlugin(TagPlugin):
 class BrowserPlugin(UserAgentPlugin):
     """
     Automatically adds the 'browser' tag from events containing interface data
-    from ``sentry.interfaes.Http``.
+    from ``sentry.interfaces.Http``.
     """
     slug = 'browsers'
     title = _('Auto Tag: Browsers')
@@ -48,23 +50,28 @@ class BrowserPlugin(UserAgentPlugin):
     tag_label = _('Browser Name')
 
     def get_tag_from_ua(self, ua):
-        if 'browser' not in ua:
+        ua = ua['user_agent']
+
+        if not ua['family']:
             return
 
-        tag = ua['browser']['name']
-        if 'version' in ua['browser']:
-            tag += ' ' + ua['browser']['version']
+        version = '.'.join(value for value in [
+            ua['major'],
+            ua['minor'],
+        ] if value)
+        tag = ua['family']
+        if version:
+            tag += ' ' + version
 
         return tag
 
-
 register(BrowserPlugin)
 
 
 class OsPlugin(UserAgentPlugin):
     """
     Automatically adds the 'os' tag from events containing interface data
-    from ``sentry.interfaes.Http``.
+    from ``sentry.interfaces.Http``.
     """
     slug = 'os'
     title = _('Auto Tag: Operating Systems')
@@ -72,21 +79,36 @@ class OsPlugin(UserAgentPlugin):
     tag_label = _('Operating System')
 
     def get_tag_from_ua(self, ua):
-        if 'flavor' in ua:
-            tag = ua['flavor']['name']
-            if 'version' in ua['flavor']:
-                tag += ' ' + ua['version']
-        elif 'os' in ua:
-            # Linux
-            tag = ua['os']['name']
-            if 'version' in ua['os']:
-                tag += ' ' + ua['version']
-            elif 'dist' in ua:
-                # Ubuntu
-                tag += ua['dist']['name']
-        else:
+        ua = ua['os']
+
+        if not ua['family']:
             return
 
+        version = '.'.join(value for value in [
+            ua['major'],
+            ua['minor'],
+            ua['patch'],
+        ] if value)
+        tag = ua['family']
+        if version:
+            tag += ' ' + version
+
         return tag
 
 register(OsPlugin)
+
+
+class DevicePlugin(UserAgentPlugin):
+    """
+    Automatically adds the 'device' tag from events containing interface data
+    from ``sentry.interfaces.Http``.
+    """
+    slug = 'device'
+    title = _('Auto Tag: Device')
+    tag = 'device'
+    tag_label = _('Device')
+
+    def get_tag_from_ua(self, ua):
+        return ua['device']['family']
+
+register(DevicePlugin)
