@@ -1,4 +1,4 @@
-(function(window, app, Backbone, jQuery, _){
+(function(window, app, Backbone, jQuery, _, moment){
     "use strict";
 
     var $ = jQuery;
@@ -11,13 +11,13 @@
         initialize: function(){
             Backbone.View.prototype.initialize.apply(this, arguments);
 
-            _.bindAll(this, 'updateCount', 'updateUsersSeen', 'updateLastSeen',
+            _.bindAll(this, 'updateCount', 'updateAllAnnotations', 'updateAnnotation', 'updateLastSeen',
                 'updateResolved', 'updateHasSeen', 'renderSparkline', 'updateBookmarked',
                 'render');
 
             this.model.on({
                 'change:count': this.updateCount,
-                'change:usersSeen': this.updateUsersSeen,
+                'change:annotations': this.updateAllAnnotations,
                 'change:lastSeen': this.updateLastSeen,
                 'change:isBookmarked': this.updateBookmarked,
                 'change:isResolved': this.updateResolved,
@@ -28,7 +28,7 @@
 
         render: function(){
             var data = this.model.toJSON();
-            data.projectUrl = app.config.urlPrefix + '/' + app.config.teamId +
+            data.projectUrl = app.config.urlPrefix + '/' + app.config.organizationId +
                 '/' + data.project.slug + '/';
             data.loggerUrl = data.projectUrl + '?logger=' + data.logger;
 
@@ -47,6 +47,7 @@
                 e.preventDefault();
                 this.bookmark();
             }, this));
+            this.updateLastSeen();
             this.renderSparkline();
             this.updateResolved();
             this.updateHasSeen();
@@ -93,7 +94,7 @@
                 type: 'post',
                 dataType: 'json',
                 success: _.bind(function(response) {
-                    this.model.set('version', response.version);
+                    this.model.set('version', response.version + 5000);
                     this.model.set('isResolved', true);
                 }, this)
             });
@@ -105,26 +106,26 @@
                 type: 'post',
                 dataType: 'json',
                 success: _.bind(function(response) {
-                    this.model.set('version', response.version);
+                    this.model.set('version', response.version + 5000);
                     this.model.set('isResolved', false);
                 }, this)
             });
         },
 
         getResolveUrl: function(){
-            return app.config.urlPrefix + '/api/' + app.config.teamId + '/' +
+            return app.config.urlPrefix + '/api/' + app.config.organizationId + '/' +
                     app.config.projectId + '/group/' + this.model.get('id') +
                     '/set/resolved/';
         },
 
         getUnresolveUrl: function(){
-            return app.config.urlPrefix + '/api/' + app.config.teamId + '/' +
+            return app.config.urlPrefix + '/api/' + app.config.organizationId + '/' +
                     app.config.projectId + '/group/' + this.model.get('id') +
                     '/set/unresolved/';
         },
 
         getBookmarkUrl: function(){
-            return app.config.urlPrefix + '/api/' + app.config.teamId + '/' + app.config.projectId + '/bookmark/';
+            return app.config.urlPrefix + '/api/' + app.config.organizationId + '/' + app.config.projectId + '/bookmark/';
         },
 
         bookmark: function(){
@@ -147,9 +148,11 @@
         },
 
         updateLastSeen: function(){
+            var dt = moment(this.model.get('lastSeen'));
             this.$el.find('.last-seen')
-                .text(app.utils.prettyDate(this.model.get('lastSeen')))
-                .attr('title', this.model.get('lastSeen'));
+                .text(dt.fromNow())
+                .data('datetime', this.model.get('lastSeen'))
+                .attr('title', dt.format('llll'));
         },
 
         updateCount: function(){
@@ -191,12 +194,12 @@
             }, 'fast');
         },
 
-        updateUsersSeen: function(){
-            var value = this.model.get('usersSeen');
+        updateAnnotation: function(annotation){
+            var value = annotation.count;
             if (value === null)
                 return;
             var new_count = app.utils.formatNumber(value);
-            var counter = this.$el.find('.tag-users');
+            var counter = this.$el.find('.annotation[data-tag="' + annotation.label + '"]');
             var digit = counter.find('span');
 
             if (digit.is(':animated'))
@@ -231,17 +234,24 @@
                 top: 0,
                 opacity: 1
             }, 'fast');
+        },
+
+        updateAllAnnotations: function(){
+            var self = this;
+            $.each(this.model.get('annotations'), function(index, annotation){
+                self.updateAnnotation(annotation);
+            });
         }
 
     });
 
     app.OrderedElementsView = Backbone.View.extend({
 
-        emptyMessage: '<div class="empty-message"><h2>No events to show.</h2><p>We\'ll notify you if that changes. In the meantime why not take a moment to become more familiar with Sentry.</p><p class="links"><a href="docs/">Installation instructions</a> <a href="settings/">Project settings</a></p></div>',
         loadingMessage: '<p>Loading...</p>',
         model: app.models.Group,
 
         defaults: {
+            emptyMessage: '<p>There is no data to show.</p>',
             maxItems: 50,
             view: Backbone.View
         },
@@ -288,7 +298,7 @@
                 this.setEmpty();
                 this.loaded = false;
             } else {
-                this.$empty.html(this.emptyMessage);
+                this.$empty.html(this.options.emptyMessage);
                 this.collection.reset(members);
                 this.loaded = true;
             }
@@ -305,16 +315,27 @@
         },
 
         addMember: function(member){
-            if (!this.hasMember(member)) {
+            var existing = this.collection.get(member.id);
+
+            function getAttr(x) {
+                if (typeof member.get === 'function') {
+                    return member.get(x);
+                } else {
+                    return member[x];
+                }
+            }
+            if (!existing) {
                 if (this.collection.length >= this.options.maxItems) {
                     // bail early if the score is too low
-                    if (member.score < this.collection.last().get('score'))
+                    if (getAttr('score') < this.collection.last().get('score'))
                         return;
 
                     // make sure we limit the number shown
                     while (this.collection.length >= this.options.maxItems)
                         this.collection.pop();
                 }
+            } else if (existing.get('version') >= (getAttr('version') || 0)) {
+                return;
             }
             this.collection.add(member, {merge: true});
         },
@@ -330,7 +351,7 @@
                 options = {};
 
             var existing = this.collection.get(member.id);
-            if (existing.get('version') > member.get('version'))
+            if (existing.get('version') >= member.get('version'))
                 return;
 
             this.collection.add(member, {
@@ -406,6 +427,8 @@
     app.GroupListView = app.OrderedElementsView.extend({
 
         defaults: {
+            emptyMessage: '<p>There is no data to show.</p>',
+            maxItems: 50,
             realtime: false,
             stream: false,
             pollUrl: null,
@@ -451,11 +474,13 @@
             }
         },
 
-        pollSuccess: function(groups){
+        pollSuccess: function(groups, _, jqXHR){
             if (!groups.length)
                 return window.setTimeout(this.poll, this.options.pollTime * 5);
 
-            this.cursor = groups[groups.length - 1].score;
+            var links = app.utils.parseLinkHeader(jqXHR.getResponseHeader('Link'));
+
+            this.options.pollUrl = links.previous;
 
             this.queue.add(groups, {merge: true});
 
@@ -488,4 +513,4 @@
 
     });
 
-}(window, app, Backbone, jQuery, _));
+}(window, app, Backbone, jQuery, _, moment));
