@@ -5,22 +5,33 @@ sentry.utils.samples
 :copyright: (c) 2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
+
 import os.path
 
 from sentry.constants import DATA_ROOT, PLATFORM_ROOTS, PLATFORM_TITLES
-from sentry.models import Group
+from sentry.event_manager import EventManager
 from sentry.utils import json
 
 
-def load_data(platform):
-    json_path = os.path.join(DATA_ROOT, 'samples', '%s.json' % (platform.encode('utf-8'),))
+def load_data(platform, default=None):
+    data = None
+    for platform in (platform, default):
+        if platform is None:
+            continue
 
-    if not os.path.exists(json_path):
+        json_path = os.path.join(DATA_ROOT, 'samples', '%s.json' % (platform.encode('utf-8'),))
+
+        if not os.path.exists(json_path):
+            continue
+
+        with open(json_path) as fp:
+            data = json.loads(fp.read())
+            break
+
+    if data is None:
         return
 
-    with open(json_path) as fp:
-        data = json.loads(fp.read())
-
     data['platform'] = platform
     data['message'] = 'This is an example %s exception' % (
         PLATFORM_TITLES.get(platform, platform.title()),)
@@ -33,6 +44,14 @@ def load_data(platform):
         ('foo', 'bar'),
         ('version', '1.0'),
     ]
+    data['extra'] = {
+        'session': {
+            'foo': 'bar',
+        },
+        'results': [1, 2, 3, 4, 5],
+        'emptyList': [],
+        'emptyMap': {},
+    }
     data['sentry.interfaces.Http'] = {
         "cookies": {},
         "url": "http://example.com/foo",
@@ -49,19 +68,20 @@ def load_data(platform):
     return data
 
 
-def create_sample_event(project, platform=None):
+def create_sample_event(project, platform=None, default=None):
     if not platform:
         platform = project.platform
 
-    if not platform:
+    if not platform and not default:
         return
 
     platform = PLATFORM_ROOTS.get(platform, platform)
 
-    data = load_data(platform)
+    data = load_data(platform, default)
 
     if not data:
         return
 
-    data = Group.objects.normalize_event_data(data)
-    return Group.objects.save_data(project.id, data, raw=True)
+    manager = EventManager(data)
+    manager.normalize()
+    return manager.save(project.id, raw=True)
