@@ -2,9 +2,11 @@
 sentry.web.frontend.admin
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import, print_function
+
 import datetime
 import logging
 import pkg_resources
@@ -16,13 +18,15 @@ from django.core.context_processors import csrf
 from django.core.mail import send_mail
 from django.core.urlresolvers import reverse
 from django.db import transaction
-from django.db.models import Sum, Count
+from django.db.models import Count
 from django.http import HttpResponseRedirect
 from django.utils import timezone
 from django.views.decorators.csrf import csrf_protect
 
+import six
+
 from sentry.app import env
-from sentry.models import Team, Project, GroupCountByMinute, User
+from sentry.models import Team, Project, User
 from sentry.plugins import plugins
 from sentry.utils.http import absolute_uri
 from sentry.web.forms import (
@@ -68,11 +72,6 @@ def manage_projects(request):
         order_by = '-date_added'
     elif sort == 'name':
         order_by = 'name'
-    elif sort == 'events':
-        project_list = project_list.annotate(
-            events=Sum('projectcountbyminute__times_seen'),
-        ).filter(projectcountbyminute__date__gte=timezone.now() - datetime.timedelta(days=1))
-        order_by = '-events'
 
     project_list = project_list.order_by(order_by)
 
@@ -114,7 +113,7 @@ def manage_users(request):
 
 
 @requires_admin
-@transaction.commit_on_success
+@transaction.atomic
 @csrf_protect
 def create_new_user(request):
     if not request.user.is_superuser:
@@ -135,7 +134,6 @@ def create_new_user(request):
 
         if form.cleaned_data['create_project']:
             project = Project.objects.create(
-                owner=user,
                 name='%s\'s New Project' % user.username.capitalize()
             )
             member = project.team.member_set.get(user=user)
@@ -161,7 +159,7 @@ def create_new_user(request):
                     body, settings.SERVER_EMAIL, [user.email],
                     fail_silently=False
                 )
-            except Exception, e:
+            except Exception as e:
                 logger = logging.getLogger('sentry.mail.errors')
                 logger.exception(e)
 
@@ -287,7 +285,7 @@ def manage_teams(request):
 
 @requires_admin
 def status_env(request):
-    reserved = ('PASSWORD', 'SECRET')
+    reserved = ('PASSWORD', 'SECRET', 'KEY')
     config = []
     for k in sorted(dir(settings)):
         v_repr = repr(getattr(settings, k))
@@ -339,8 +337,8 @@ def status_mail(request):
                 body, settings.SERVER_EMAIL, [request.user.email],
                 fail_silently=False
             )
-        except Exception, e:
-            form.errors['__all__'] = [unicode(e)]
+        except Exception as e:
+            form.errors['__all__'] = [six.text_type(e)]
 
     return render_to_response('sentry/admin/status/mail.html', {
         'form': form,
@@ -355,15 +353,12 @@ def status_mail(request):
 
 @requires_admin
 def stats(request):
+    new_projects = Project.objects.filter(
+        date_added__gte=timezone.now() - datetime.timedelta(hours=24),
+    ).count()
     statistics = (
         ('Projects', Project.objects.count()),
-        ('Projects (24h)', Project.objects.filter(
-            date_added__gte=timezone.now() - datetime.timedelta(hours=24),
-        ).count()),
-        ('Events', GroupCountByMinute.objects.aggregate(x=Sum('times_seen'))['x'] or 0),
-        ('Events (24h)', GroupCountByMinute.objects.filter(
-            date__gte=timezone.now() - datetime.timedelta(hours=24),
-        ).aggregate(x=Sum('times_seen'))['x'] or 0)
+        ('Projects (24h)', new_projects),
     )
 
     return render_to_response('sentry/admin/stats.html', {
