@@ -5,6 +5,8 @@ sentry.web.frontend.projects.plugins
 :copyright: (c) 2012 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
+
 from django.contrib import messages
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
@@ -12,15 +14,15 @@ from django.http import HttpResponseRedirect
 from django.views.decorators.csrf import csrf_protect
 from django.utils.translation import ugettext_lazy as _
 
-from sentry.constants import MEMBER_OWNER
+from sentry.constants import MEMBER_ADMIN
 from sentry.plugins import plugins
 from sentry.web.decorators import has_access
 from sentry.web.helpers import render_to_response, plugin_config
 
 
-@has_access(MEMBER_OWNER)
+@has_access(MEMBER_ADMIN)
 @csrf_protect
-def manage_plugins(request, team, project):
+def manage_plugins(request, organization, project):
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project)
     if result is False and not request.user.is_superuser:
         return HttpResponseRedirect(reverse('sentry'))
@@ -39,7 +41,8 @@ def manage_plugins(request, team, project):
 
     context = csrf(request)
     context.update({
-        'team': team,
+        'organization': organization,
+        'team': project.team,
         'page': 'plugins',
         'project': project,
     })
@@ -47,16 +50,16 @@ def manage_plugins(request, team, project):
     return render_to_response('sentry/projects/plugins/list.html', context, request)
 
 
-@has_access(MEMBER_OWNER)
+@has_access(MEMBER_ADMIN)
 @csrf_protect
-def configure_project_plugin(request, team, project, slug):
+def configure_project_plugin(request, organization, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.team.slug, project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.organization.slug, project.slug]))
 
     if not plugin.can_enable_for_projects():
-        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.team.slug, project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.organization.slug, project.slug]))
 
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
@@ -64,7 +67,7 @@ def configure_project_plugin(request, team, project, slug):
 
     form = plugin.project_conf_form
     if form is None:
-        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.team.slug, project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.organization.slug, project.slug]))
 
     action, view = plugin_config(plugin, project, request)
     if action == 'redirect':
@@ -76,7 +79,8 @@ def configure_project_plugin(request, team, project, slug):
 
     context = csrf(request)
     context.update({
-        'team': team,
+        'organization': organization,
+        'team': project.team,
         'page': 'plugin',
         'title': plugin.get_title(),
         'view': view,
@@ -88,16 +92,16 @@ def configure_project_plugin(request, team, project, slug):
     return render_to_response('sentry/projects/plugins/configure.html', context, request)
 
 
-@has_access(MEMBER_OWNER)
+@has_access(MEMBER_ADMIN)
 @csrf_protect
-def reset_project_plugin(request, team, project, slug):
+def reset_project_plugin(request, organization, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.organization.slug, project.slug, slug]))
 
     if not plugin.is_enabled(project):
-        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
+        return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.organization.slug, project.slug, slug]))
 
     result = plugins.first('has_perm', request.user, 'configure_project_plugin', project, plugin)
     if result is False and not request.user.is_superuser:
@@ -105,18 +109,18 @@ def reset_project_plugin(request, team, project, slug):
 
     plugin.reset_options(project=project)
 
-    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug]))
+    return HttpResponseRedirect(reverse('sentry-configure-project-plugin', args=[project.organization.slug, project.slug, slug]))
 
 
-@has_access(MEMBER_OWNER)
+@has_access(MEMBER_ADMIN)
 @csrf_protect
-def enable_project_plugin(request, team, project, slug):
+def enable_project_plugin(request, organization, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-manage-project-plugins', args=[project.team.slug, project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project-plugins', args=[project.organization.slug, project.slug]))
 
-    redirect_to = reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug])
+    redirect_to = reverse('sentry-configure-project-plugin', args=[project.organization.slug, project.slug, slug])
 
     if plugin.is_enabled(project) or not plugin.can_enable_for_projects():
         return HttpResponseRedirect(redirect_to)
@@ -130,15 +134,15 @@ def enable_project_plugin(request, team, project, slug):
     return HttpResponseRedirect(redirect_to)
 
 
-@has_access(MEMBER_OWNER)
+@has_access(MEMBER_ADMIN)
 @csrf_protect
-def disable_project_plugin(request, team, project, slug):
+def disable_project_plugin(request, organization, project, slug):
     try:
         plugin = plugins.get(slug)
     except KeyError:
-        return HttpResponseRedirect(reverse('sentry-manage-project-plugins', args=[project.team.slug, project.slug]))
+        return HttpResponseRedirect(reverse('sentry-manage-project-plugins', args=[project.organization.slug, project.slug]))
 
-    redirect_to = reverse('sentry-configure-project-plugin', args=[project.team.slug, project.slug, slug])
+    redirect_to = reverse('sentry-configure-project-plugin', args=[project.organization.slug, project.slug, slug])
 
     if not (plugin.can_disable and plugin.is_enabled(project) and plugin.can_enable_for_projects()):
         return HttpResponseRedirect(redirect_to)
